# loki

## Objects

 * <span class="badge object-type-enum"></span> [LokiQueryDirection](./object-LokiQueryDirection.md)
 * <span class="badge object-type-enum"></span> [LokiQueryType](./object-LokiQueryType.md)
 * <span class="badge object-type-enum"></span> [QueryEditorMode](./object-QueryEditorMode.md)
 * <span class="badge object-type-enum"></span> [SupportingQueryType](./object-SupportingQueryType.md)
 * <span class="badge object-type-class"></span> [Dataquery](./object-Dataquery.md)
## Builders

 * <span class="badge builder"></span> [Dataquery](./builder-Dataquery.md)
